
Tadv = [155.70 152.24 ]; % adv CA: green / brown
Trec = [149.97 98.97  ]; % rec CA: green / brown
Rho = [1 0.46 0.23 0.67]; % rho: green / brown / brown min / brown max
Phi = [0.25 0.2 0.3]; %0.2 0.3
R1 = [1.16 1.08 1.24]; % roughness of green leaf
R2 = [1.07 1.05 1.09]; % roughness of brown leaf
Tr = [117.08 85.88]; % flat wax surface adv and rec contact angle
Tr2 = acosd(cosd([111.96 76.54])/R1(1))% chloroform treated leaf CA
er = [ 11.40 15.95 5.50 9.77 6.99 ]; % Experimental hysteresis error

%%%%%%%%%%%%%%%%

Delta_theta = abs( diff(Tr) );
Delta_G = R1(1)*Phi(1)*sind(mean(Tr))./sind(mean([Tadv(1) Trec(1)]))*Delta_theta; % Green leaf hysteresis
Delta_F = (Rho(2)*R2(1)*Phi(1) + (1-Rho(2))*R2(1))*sind(mean(Tr))./sind(mean([Tadv(1) Trec(1)]))*Delta_theta; % Brown leaf hysteresis
Delta_F2 = (Rho(2)*R2(1)*Phi(1))*sind(mean(Tr))./sind(mean([Tadv(1) Trec(1)]))*Delta_theta ...
    + (1-Rho(2))*R2(1)*sind(mean(Tr2))./sind(mean([Tadv(1) Trec(1)]))*abs( diff(Tr2) ); % Brown leaf hysteresis using two theta
Delta_F3 = (Rho(3)*R2(1)*Phi(1) + (1-Rho(3))*R2(1))*sind(mean(Tr))./sind(mean([Tadv(1) Trec(1)]))*Delta_theta;

CA_V = [161.77 131.39]; % Vacuum treated leaf CA : adv / rec
CA_H = [126.83 85.85];  % Heat treated leaf CA : adv / rec
Delta_V = (1*1.15*Phi(1))*sind(mean(Tr))./sind(mean(CA_V))*Delta_theta; % Vacuum treated leaf hysteresis
Delta_H = (1.14)*sind(mean(Tr))./sind(mean(CA_H))*Delta_theta; % Heat treated leaf hysteresis
Delta = [Delta_G; Delta_F; Delta_H; Delta_V; 0];

col = 1/255*[217 83 25; 126 47 142]; %[126 47 142];
x1 = [ 0.85 1.15 ; 1.85 2.15 ; 2.85 3.15 ; 3.85 4.15 ; 5 5 ; ];
w = [0.3, 0.3];

Data_Statistics;

figure(11); clf; hold on; 
for i = 1:size(Adv,1)
    
    %%%%% Adv angles %%%%%
    for j = 1:2 %% 1= Rec; 2 = Adv; 3 = Mean; 4 = Theory;
        if j == 1, TT = Hys(:,1); TJ = Hys; elseif j == 2, TT = Delta; end
        
        b = patch( x1(i,j)*[1 1 1 1]+w(j)/2*[1 1 -1 -1], TT(i)*[0 1 1 0], col(j,:) );
        if j == 1, b1=b; elseif j == 2, b2=b; end
        
        if j ==1            %%% To plot min and max
            plot(x1(i,j)*[1 1], [TJ(i,4) TJ(i,3)], 'k' , 'linewidth', 1)
            plot(x1(i,j)*[1 1]+w(j)/4*[1 -1], TJ(i,4)*[1 1], 'k' , 'linewidth', 2)
            plot(x1(i,j)*[1 1]+w(j)/4*[1 -1], TJ(i,3)*[1 1], 'k' , 'linewidth', 2)
            %%% Quartile %%%%%
            plot(x1(i,j)*[1 1 1 1 1]+w(j)/4*[1 -1 -1 1 1], [TJ(i,5)*[1 1], TJ(i,6)*[1 1], TJ(i,5)], 'k' , 'linewidth', 1.5)
            %%%% Median %%%%
            plot(x1(i,j)*[1 1]+w(j)/4*[1 -1], TJ(i,7)*[1 1], 'r' , 'linewidth', 2)
        end
    end
end


% figure(11); clf; hold on;
% a = fill([1 1 1.3 1.3], [0 Tadv(1)-Trec(1)*[1 1] 0],  1/255*[217 83 25]); % Experimental Green leaf hysteresis
% b = fill([1.3 1.3 1.6 1.6], [0 Delta_G*[1 1] 0],  1/255*[126 47 142]); % Green leaf hysteresis
% fill([1.8 1.8 2.1 2.1], [0 Tadv(2)-Trec(2)*[1 1] 0],  1/255*[217 83 25]); % Experimental Brown leaf hysteresis
% fill([2.1 2.1 2.4 2.4], [0 Delta_F*[1 1] 0],  1/255*[126 47 142]); % Brown leaf hysteresis
% fill([2.6 2.6 2.9 2.9], [0 abs(diff(CA_H))*[1 1] 0],  1/255*[217 83 25]); % Experimental Heat leaf hysteresis
% fill([2.9 2.9 3.2 3.2], [0 Delta_H*[1 1] 0],  1/255*[126 47 142]); % Heat leaf hysteresis
% fill([3.3 3.3 3.6 3.6], [0 abs(diff(CA_V))*[1 1] 0],  1/255*[217 83 25]); % Experimental Vacuum leaf hysteresis
% fill([3.6 3.6 3.9 3.9], [0 Delta_V*[1 1] 0],  1/255*[126 47 142]); % Vacuum leaf hysteresis

box on; grid on;
%xlabel('Fat surface (\theta)', 'fontsize', 20)
ylabel('Contact-angle Hysteresis (\circ)', 'fontsize', 30)
% set(gca, 'fontsize', 20 , ...
%     'XTick', [1:4], 'XTickLabel', {'Green'; 'Brown'; 'Heat'; 'Vacuum'})
set(gca,'fontsize', 30)
legend([b1 b2], {'Experimental', 'Theoretical'});
ax = gca;
ax.XTick = [1 2 3 4 5];
ax.XTickLabels = {'Green','Brown','Heat','Vacuum','Flat wax'};
ax.XTickLabelRotation = 45;
axis([0.6 5.4 0 80])

if 0 % just for test
    figure(2); clf; hold on;
    
    
    
    T = linspace(80, 120, 50);
    
    Th = acosd( R1(1)*Phi(1)*cosd(T) - R1(1)*(1-Phi(1)) );
    plot(T, Th, 'b-', 'linewidth', 3);
    Th = acosd( R1(1)*Phi(2)*cosd(T) - R1(1)*(1-Phi(2)) );
    plot(T, Th, 'b--', 'linewidth', 1);
    Th = acosd( R1(1)*Phi(3)*cosd(T) - R1(1)*(1-Phi(3)) );
    plot(T, Th, 'b--', 'linewidth', 1);
    Th = acosd( R1(2)*Phi(1)*cosd(T) - R1(2)*(1-Phi(1)) );
    plot(T, Th, 'b-.', 'linewidth', 1);
    Th = acosd( R1(3)*Phi(1)*cosd(T) - R1(3)*(1-Phi(1)) );
    plot(T, Th, 'b-.', 'linewidth', 1);
    % Th = acosd( R(1)*cosd(T) )
    % plot(T, Th, 'c-', 'linewidth', 3);
    % Th = acosd( Rho(1)*( R(1)*Phi*cosd(T) - R(1)*(1-Phi)) + (1-Rho(1))*R(1)*cosd(T) )
    % plot(T, Th, 'k-', 'linewidth', 3);
    
    % Th = acosd( R(2)*Phi*cosd(T) - R(2)*(1-Phi) )
    % plot(T, Th, 'b-', 'linewidth', 1);
    % Th = acosd( R(2)*cosd(T) )
    % plot(T, Th, 'c-', 'linewidth', 1);
    Th = acosd( Rho(2)*( R2(1)*Phi(1)*cosd(T) - R2(1)*(1-Phi(1))) + (1-Rho(2))*R2(1)*cosd(T) );
    plot(T, Th, 'k-', 'linewidth', 3);
    Th = acosd( Rho(2)*( R2(1)*Phi(2)*cosd(T) - R2(1)*(1-Phi(2))) + (1-Rho(2))*R2(1)*cosd(T) );
    plot(T, Th, 'k--', 'linewidth', 1);
    Th = acosd( Rho(2)*( R2(1)*Phi(3)*cosd(T) - R2(1)*(1-Phi(3))) + (1-Rho(2))*R2(1)*cosd(T) );
    plot(T, Th, 'k--', 'linewidth', 1);
    Th = acosd( Rho(2)*( R2(2)*Phi(1)*cosd(T) - R2(2)*(1-Phi(1))) + (1-Rho(2))*R2(2)*cosd(T) );
    plot(T, Th, 'k-.', 'linewidth', 1);
    Th = acosd( Rho(2)*( R2(3)*Phi(1)*cosd(T) - R2(3)*(1-Phi(1))) + (1-Rho(2))*R2(3)*cosd(T) );
    plot(T, Th, 'k-.', 'linewidth', 1);
    Th = acosd( Rho(3)*( R2(1)*Phi(1)*cosd(T) - R2(1)*(1-Phi(1))) + (1-Rho(3))*R2(1)*cosd(T) );
    plot(T, Th, 'k-', 'linewidth', 1);
    Th = acosd( Rho(4)*( R2(1)*Phi(1)*cosd(T) - R2(1)*(1-Phi(1))) + (1-Rho(4))*R2(1)*cosd(T) );
    plot(T, Th, 'k-', 'linewidth', 1);
    
    plot(Tr(1), Tadv(1), 'go', 'markerfacecolor', 'g', 'markersize', 15)
    plot(Tr(2), Trec(1), 'go', 'markerfacecolor', 'w', 'linewidth', 4, 'markersize', 15)
    plot(mean(Tr), mean([Tadv(1) Trec(1)]), 'g^', 'markerfacecolor', 'g', 'markersize', 15)
    plot(Tr(1), Tadv(2), 'ro', 'markerfacecolor', 'r', 'markersize', 15)
    plot(Tr(2), Trec(2), 'ro', 'markerfacecolor', 'w', 'linewidth', 4, 'markersize', 15)
    plot(mean(Tr), mean([Tadv(2) Trec(2)]), 'r^', 'markerfacecolor', 'r', 'markersize', 15)
    
    plot(Tr(1)*[1 1], [90 180], 'k')
    plot(Tr(2)*[1 1], [90 180], 'k')
    
    plot([80 120], Tadv(1)*[1 1], 'g', 'linewidth', 3)
    plot([80 120], Tadv(2)*[1 1], 'r', 'linewidth', 3)
    
    plot([80 120], Trec(1)*[1 1], 'g', 'linewidth', 3)
    plot([80 120], Trec(2)*[1 1], 'r', 'linewidth', 3)

box on; grid on;
xlabel('Fat surface (\theta)', 'fontsize', 20)
ylabel('Leaf surface (\theta^*)', 'fontsize', 20)
set(gca, 'fontsize', 20)
end



